# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/nativeact/v1/nativeact.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/app/nativeact/v1/nativeact.proto\x12\x19\x62ilibili.app.nativeact.v1\x1a\x19google/protobuf/any.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"?\n\x05\x42\x61\x64ge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x62g_color\x18\x02 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x03 \x01(\t\"d\n\x0f\x43\x61rouselImgCard\x12\x15\n\rcontent_style\x18\x01 \x01(\x03\x12:\n\x06images\x18\x02 \x03(\x0b\x32*.bilibili.app.nativeact.v1.CarouselImgItem\"\x90\x01\n\x0f\x43\x61rouselImgItem\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0e\n\x06length\x18\x03 \x01(\x03\x12\r\n\x05width\x18\x04 \x01(\x03\x12\x32\n\x07top_tab\x18\x05 \x01(\x0b\x32!.bilibili.app.nativeact.v1.TopTab\x12\x0e\n\x06height\x18\x06 \x01(\x03\"z\n\x10\x43\x61rouselWordCard\x12\x15\n\rcontent_style\x18\x01 \x01(\x03\x12\x13\n\x0bscroll_type\x18\x02 \x01(\x03\x12:\n\x05words\x18\x03 \x03(\x0b\x32+.bilibili.app.nativeact.v1.CarouselWordItem\"#\n\x10\x43\x61rouselWordItem\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\x98\x05\n\x05\x43olor\x12\x10\n\x08\x62g_color\x18\x01 \x01(\t\x12\x13\n\x0btitle_color\x18\x02 \x01(\t\x12\x16\n\x0etop_font_color\x18\x03 \x01(\t\x12\x19\n\x11\x62ottom_font_color\x18\x04 \x01(\t\x12\x12\n\nfont_color\x18\x05 \x01(\t\x12\x1d\n\x15text_title_font_color\x18\x06 \x01(\t\x12\x17\n\x0findicator_color\x18\x07 \x01(\t\x12\x15\n\rcard_bg_color\x18\x08 \x01(\t\x12\x1d\n\x15\x63\x61rd_title_font_color\x18\t \x01(\t\x12\x1b\n\x13\x63\x61rd_title_bg_color\x18\n \x01(\t\x12\x1c\n\x14view_more_font_color\x18\x0b \x01(\t\x12\x1a\n\x12view_more_bg_color\x18\x0c \x01(\t\x12\x16\n\x0etimeline_color\x18\r \x01(\t\x12\x17\n\x0frcmd_font_color\x18\x0e \x01(\t\x12\x1b\n\x13subtitle_font_color\x18\x0f \x01(\t\x12\x1b\n\x13selected_font_color\x18\x10 \x01(\t\x12\x19\n\x11selected_bg_color\x18\x11 \x01(\t\x12\x1d\n\x15unselected_font_color\x18\x12 \x01(\t\x12\x1b\n\x13unselected_bg_color\x18\x13 \x01(\t\x12\x1e\n\x16nt_selected_font_color\x18\x14 \x01(\t\x12\x1c\n\x14nt_selected_bg_color\x18\x15 \x01(\t\x12 \n\x18nt_unselected_font_color\x18\x16 \x01(\t\x12\x1e\n\x16nt_unselected_bg_color\x18\x17 \x01(\t\x12\x1a\n\x12progress_bar_color\x18\x18 \x01(\t\"m\n\x12\x44ynamicActMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"D\n\x0b\x44ynamicCard\x12\x35\n\x07\x64ynamic\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"j\n\x0f\x44ynamicMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"\x84\x01\n\rDynamicParams\x12)\n\x0b\x66\x65\x65\x64_offset\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x12\n\nlast_group\x18\x03 \x01(\x03\x12\x11\n\tmodule_id\x18\x04 \x01(\x03\x12\x11\n\tsort_type\x18\x05 \x01(\x03\"\xf7\x01\n\nDynamicReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32(.bilibili.app.nativeact.v1.DynamicParams\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x15\n\ris_cold_start\x18\x06 \x01(\x08\x12\x17\n\x0fprimary_page_id\x18\x07 \x01(\x03\"@\n\x0b\x44ynamicResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"1\n\x0c\x45\x64itorParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x11\n\tmodule_id\x18\x02 \x01(\x03\"\xfa\x03\n\x13\x45\x64itorRecommendCard\x12\x10\n\x08top_icon\x18\x01 \x01(\t\x12\x13\n\x0btop_content\x18\x02 \x01(\t\x12\x13\n\x0b\x62ottom_icon\x18\x03 \x01(\t\x12\x16\n\x0e\x62ottom_content\x18\x04 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x11\n\tposition1\x18\x08 \x01(\t\x12\x11\n\tposition2\x18\t \x01(\t\x12\x11\n\tposition3\x18\n \x01(\t\x12\x11\n\tposition4\x18\x0b \x01(\t\x12\x11\n\tposition5\x18\x0c \x01(\t\x12/\n\x05share\x18\r \x01(\x0b\x32 .bilibili.app.nativeact.v1.Share\x12/\n\x05\x62\x61\x64ge\x18\x0e \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x38\n\nreport_dic\x18\x0f \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x33\n\x07setting\x18\x10 \x01(\x0b\x32\".bilibili.app.nativeact.v1.Setting\x12\x13\n\x0bmiddle_icon\x18\x11 \x01(\t\x12\x15\n\rresource_type\x18\x12 \x01(\t\"q\n\tEditorReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.EditorParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"?\n\nEditorResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"X\n\x08GameCard\x12\r\n\x05image\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\"\xca\x01\n\nHeaderCard\x12\x12\n\nuser_image\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\x12\x17\n\x0fsponsor_content\x18\x03 \x01(\t\x12\x18\n\x10high_light_image\x18\x04 \x01(\t\x12\x17\n\x0flow_light_image\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12\x10\n\x08view_num\x18\x07 \x01(\t\x12\x13\n\x0b\x64iscuss_num\x18\x08 \x01(\t\x12\x15\n\ris_subscribed\x18\t \x01(\x08\"\x1f\n\x0eImageTitleCard\x12\r\n\x05image\x18\x01 \x01(\t\"\xde\x02\n\x08IndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_from\x18\x02 \x01(\t\x12\x12\n\ndynamic_id\x18\x03 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x04 \x01(\t\x12\x0e\n\x06tab_id\x18\x05 \x01(\x03\x12\x15\n\rtab_module_id\x18\x06 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x07 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x08 \x01(\t\x12\x13\n\x0b\x63urrent_tab\x18\t \x01(\t\x12\x43\n\x0bplayer_args\x18\n \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x0b \x01(\x05\x12\x15\n\ris_cold_start\x18\x0c \x01(\x08\x12\x17\n\x0fprimary_page_id\x18\r \x01(\x03\x12\x10\n\x08tab_from\x18\x0e \x01(\t\"\xbc\x01\n\x0eInlineIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x02 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x15\n\ris_cold_start\x18\x06 \x01(\x08\"T\n\x0cLayerDynamic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x35\n\x07\x64ynamic\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"R\n\x08LiveCard\x12\x10\n\x08has_live\x18\x01 \x01(\x05\x12\x34\n\x07\x63ontent\x18\x02 \x01(\x0b\x32#.bilibili.app.nativeact.v1.LiveItem\"\xb7\x02\n\x08LiveItem\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x0b\n\x03uid\x18\x02 \x01(\x03\x12\x13\n\x0blive_status\x18\x03 \x01(\x03\x12\x11\n\troom_type\x18\x04 \x01(\x03\x12\x11\n\tplay_type\x18\x05 \x01(\x03\x12\r\n\x05title\x18\x06 \x01(\t\x12\r\n\x05\x63over\x18\x07 \x01(\t\x12\x0e\n\x06online\x18\x08 \x01(\x03\x12\x0f\n\x07\x61rea_id\x18\t \x01(\x03\x12\x11\n\tarea_name\x18\n \x01(\t\x12\x16\n\x0eparent_area_id\x18\x0b \x01(\x03\x12\x18\n\x10parent_area_name\x18\x0c \x01(\t\x12\x18\n\x10live_screen_type\x18\r \x01(\x03\x12\x15\n\rlast_end_time\x18\x0e \x01(\x03\x12\x0c\n\x04link\x18\x0f \x01(\t\x12\x0f\n\x07live_id\x18\x10 \x01(\x03\"\xb1\x02\n\x06Module\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\x03\x12\x36\n\x0cmodule_color\x18\x03 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Color\x12:\n\x0emodule_setting\x18\x04 \x01(\x0b\x32\".bilibili.app.nativeact.v1.Setting\x12;\n\x0cmodule_items\x18\x05 \x03(\x0b\x32%.bilibili.app.nativeact.v1.ModuleItem\x12\x16\n\x0esubpage_params\x18\x06 \x01(\t\x12\x13\n\x0bmodule_ukey\x18\x07 \x01(\t\x12\x10\n\x08has_more\x18\x08 \x01(\x08\x12\x0f\n\x07is_feed\x18\t \x01(\x08\"\xcf\t\n\nModuleItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61rd_id\x18\x02 \x01(\t\x12O\n\x15\x65\x64itor_recommend_card\x18\n \x01(\x0b\x32..bilibili.app.nativeact.v1.EditorRecommendCardH\x00\x12J\n\x12participation_card\x18\x0b \x01(\x0b\x32,.bilibili.app.nativeact.v1.ParticipationCardH\x00\x12<\n\x0bheader_card\x18\x0c \x01(\x0b\x32%.bilibili.app.nativeact.v1.HeaderCardH\x00\x12>\n\x0c\x64ynamic_card\x18\r \x01(\x0b\x32&.bilibili.app.nativeact.v1.DynamicCardH\x00\x12\x38\n\ttext_card\x18\x0e \x01(\x0b\x32#.bilibili.app.nativeact.v1.TextCardH\x00\x12\x43\n\x0ftext_title_card\x18\x0f \x01(\x0b\x32(.bilibili.app.nativeact.v1.TextTitleCardH\x00\x12\x45\n\x10image_title_card\x18\x10 \x01(\x0b\x32).bilibili.app.nativeact.v1.ImageTitleCardH\x00\x12G\n\x11\x64ynamic_more_card\x18\x11 \x01(\x0b\x32*.bilibili.app.nativeact.v1.DynamicMoreCardH\x00\x12N\n\x15\x64ynamic_act_more_card\x18\x12 \x01(\x0b\x32-.bilibili.app.nativeact.v1.DynamicActMoreCardH\x00\x12\x38\n\tlive_card\x18\x13 \x01(\x0b\x32#.bilibili.app.nativeact.v1.LiveCardH\x00\x12G\n\x11\x63\x61rousel_img_card\x18\x14 \x01(\x0b\x32*.bilibili.app.nativeact.v1.CarouselImgCardH\x00\x12I\n\x12\x63\x61rousel_word_card\x18\x15 \x01(\x0b\x32+.bilibili.app.nativeact.v1.CarouselWordCardH\x00\x12@\n\rresource_card\x18\x16 \x01(\x0b\x32\'.bilibili.app.nativeact.v1.ResourceCardH\x00\x12I\n\x12resource_more_card\x18\x17 \x01(\x0b\x32+.bilibili.app.nativeact.v1.ResourceMoreCardH\x00\x12\x38\n\tgame_card\x18\x18 \x01(\x0b\x32#.bilibili.app.nativeact.v1.GameCardH\x00\x12:\n\nvideo_card\x18\x19 \x01(\x0b\x32$.bilibili.app.nativeact.v1.VideoCardH\x00\x12\x43\n\x0fvideo_more_card\x18\x1a \x01(\x0b\x32(.bilibili.app.nativeact.v1.VideoMoreCardH\x00\x42\r\n\x0b\x63\x61rd_detail\"\x91\x04\n\x08PageResp\x12\x11\n\tis_online\x18\x01 \x01(\x08\x12\x1d\n\x15ignore_app_dark_theme\x18\x02 \x01(\x08\x12\x34\n\npage_color\x18\x03 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Color\x12\x38\n\npage_share\x18\x04 \x01(\x0b\x32$.bilibili.app.nativeact.v1.PageShare\x12\x36\n\x0bpage_header\x18\x05 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x38\n\rparticipation\x18\x06 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x36\n\x0bmodule_list\x18\x07 \x03(\x0b\x32!.bilibili.app.nativeact.v1.Module\x12\x17\n\x0fis_dynamic_feed\x18\x08 \x01(\x08\x12>\n\rlayer_dynamic\x18\t \x01(\x0b\x32\'.bilibili.app.nativeact.v1.LayerDynamic\x12\x16\n\x0eis_editor_feed\x18\n \x01(\x08\x12\x14\n\x0csponsor_type\x18\x0b \x01(\x03\x12\x32\n\x07top_tab\x18\x0c \x01(\x0b\x32!.bilibili.app.nativeact.v1.TopTab\"n\n\tPageShare\x12\x0c\n\x04type\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x12\n\ninside_uri\x18\x05 \x01(\t\x12\x13\n\x0boutside_uri\x18\x06 \x01(\t\"{\n\x11ParticipationCard\x12\r\n\x05image\x18\x01 \x01(\t\x12\x16\n\x0eselected_image\x18\x02 \x01(\t\x12?\n\x05items\x18\x03 \x03(\x0b\x32\x30.bilibili.app.nativeact.v1.ParticipationCardItem\"P\n\x15ParticipationCardItem\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\"@\n\x0fPlayerDimension\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x08\"\xa9\x01\n\tReportDic\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\t\x12\x13\n\x0bseason_type\x18\x02 \x01(\t\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x0b\n\x03\x63id\x18\x04 \x01(\x03\x12\x10\n\x08sub_type\x18\x05 \x01(\x05\x12\r\n\x05\x65p_id\x18\x06 \x01(\x03\x12\x12\n\nis_preview\x18\x07 \x01(\x05\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x13\n\x0b\x61uthor_name\x18\t \x01(\t\"\xc7\x02\n\x0cResourceCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x18\n\x10\x63over_right_text\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text1\x18\x05 \x01(\t\x12\x18\n\x10\x63over_left_icon1\x18\x06 \x01(\x03\x12\x18\n\x10\x63over_left_text2\x18\x07 \x01(\t\x12\x18\n\x10\x63over_left_icon2\x18\x08 \x01(\x03\x12/\n\x05\x62\x61\x64ge\x18\t \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x38\n\nreport_dic\x18\n \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x15\n\rresource_type\x18\x0b \x01(\t\"k\n\x10ResourceMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"\\\n\x0eResourceParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x14\n\x0ctopic_offset\x18\x02 \x01(\t\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\x12\x11\n\tsort_type\x18\x04 \x01(\x03\"u\n\x0bResourceReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x39\n\x06params\x18\x02 \x01(\x0b\x32).bilibili.app.nativeact.v1.ResourceParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\"A\n\x0cResourceResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"\xf3\x02\n\x07Setting\x12\x1b\n\x13\x64isplay_more_button\x18\x01 \x01(\x08\x12\x15\n\rdisplay_title\x18\x02 \x01(\x08\x12\x15\n\rauto_carousel\x18\x03 \x01(\x08\x12\x1a\n\x12top_tab_follow_img\x18\x04 \x01(\x08\x12\x19\n\x11top_tab_fade_away\x18\x05 \x01(\x08\x12\x11\n\tauto_play\x18\x06 \x01(\x08\x12\x1d\n\x15\x64isplay_unfold_button\x18\x07 \x01(\x08\x12\x13\n\x0b\x64isplay_num\x18\x08 \x01(\x08\x12\x18\n\x10\x64isplay_view_num\x18\t \x01(\x08\x12\x1d\n\x15\x64isplay_subscribe_btn\x18\n \x01(\x08\x12\x13\n\x0bunfold_rest\x18\x0b \x01(\x08\x12\x1c\n\x14\x64isplay_progress_num\x18\x0c \x01(\x08\x12\x18\n\x10\x64isplay_node_num\x18\r \x01(\x08\x12\x19\n\x11\x64isplay_node_desc\x18\x0e \x01(\x08\"U\n\x05Share\x12\x15\n\rdisplay_later\x18\x01 \x01(\x08\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x03 \x01(\t\x12\x12\n\nshare_type\x18\x04 \x01(\x03\"a\n\x0bSubpageData\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\x12\x33\n\x04tabs\x18\x03 \x03(\x0b\x32%.bilibili.app.nativeact.v1.SubpageTab\"*\n\nSubpageTab\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\"\xd2\x01\n\x0bTabIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x02 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x17\n\x0fprimary_page_id\x18\x05 \x01(\x03\x12\x12\n\nlocal_time\x18\x06 \x01(\x05\x12\x15\n\ris_cold_start\x18\x07 \x01(\x08\"\x18\n\x08TextCard\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x1e\n\rTextTitleCard\x12\r\n\x05title\x18\x01 \x01(\t\"\x9f\x01\n\x06TopTab\x12\x11\n\tbg_image1\x18\x01 \x01(\t\x12\x11\n\tbg_image2\x18\x02 \x01(\t\x12\x15\n\rtab_top_color\x18\x03 \x01(\t\x12\x18\n\x10tab_middle_color\x18\x04 \x01(\t\x12\x18\n\x10tab_bottom_color\x18\x05 \x01(\t\x12\x12\n\nfont_color\x18\x06 \x01(\t\x12\x10\n\x08\x62\x61r_type\x18\x07 \x01(\x03\"\xb8\x02\n\rTopicIndexReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_from\x18\x02 \x01(\t\x12\x12\n\ndynamic_id\x18\x03 \x01(\x03\x12\x14\n\x0cshare_origin\x18\x04 \x01(\t\x12\x0e\n\x06tab_id\x18\x05 \x01(\x03\x12\x15\n\rtab_module_id\x18\x06 \x01(\x03\x12\x15\n\rhttps_url_req\x18\x07 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x08 \x01(\t\x12\x13\n\x0b\x63urrent_tab\x18\t \x01(\t\x12\x43\n\x0bplayer_args\x18\n \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nlocal_time\x18\x0b \x01(\x05\x12\x15\n\ris_cold_start\x18\x0c \x01(\x08\"\x87\x03\n\tVideoCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x17\n\x0f\x63over_image_uri\x18\x02 \x01(\t\x12\x18\n\x10\x63over_left_text1\x18\x03 \x01(\t\x12\x18\n\x10\x63over_left_text2\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_text3\x18\x05 \x01(\t\x12\x0b\n\x03uri\x18\x06 \x01(\t\x12/\n\x05\x62\x61\x64ge\x18\x07 \x01(\x0b\x32 .bilibili.app.nativeact.v1.Badge\x12\x36\n\x06rights\x18\x08 \x01(\x0b\x32&.bilibili.app.nativeact.v1.VideoRights\x12=\n\tdimension\x18\t \x01(\x0b\x32*.bilibili.app.nativeact.v1.PlayerDimension\x12\x38\n\nreport_dic\x18\n \x01(\x0b\x32$.bilibili.app.nativeact.v1.ReportDic\x12\x15\n\rresource_type\x18\x0b \x01(\t\"h\n\rVideoMoreCard\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12<\n\x0csubpage_data\x18\x03 \x01(\x0b\x32&.bilibili.app.nativeact.v1.SubpageData\"Y\n\x0bVideoParams\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x14\n\x0ctopic_offset\x18\x02 \x01(\t\x12\x11\n\tmodule_id\x18\x03 \x01(\x03\x12\x11\n\tsort_type\x18\x04 \x01(\x03\"o\n\x08VideoReq\x12\x12\n\nraw_params\x18\x01 \x01(\t\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32&.bilibili.app.nativeact.v1.VideoParams\x12\x17\n\x0fprimary_page_id\x18\x03 \x01(\x03\">\n\tVideoResp\x12\x31\n\x06module\x18\x01 \x01(\x0b\x32!.bilibili.app.nativeact.v1.Module\"F\n\x0bVideoRights\x12\x0f\n\x07ugc_pay\x18\x01 \x01(\x08\x12\x16\n\x0eis_cooperation\x18\x02 \x01(\x08\x12\x0e\n\x06is_pgc\x18\x03 \x01(\x08\x62\x06proto3')



_BADGE = DESCRIPTOR.message_types_by_name['Badge']
_CAROUSELIMGCARD = DESCRIPTOR.message_types_by_name['CarouselImgCard']
_CAROUSELIMGITEM = DESCRIPTOR.message_types_by_name['CarouselImgItem']
_CAROUSELWORDCARD = DESCRIPTOR.message_types_by_name['CarouselWordCard']
_CAROUSELWORDITEM = DESCRIPTOR.message_types_by_name['CarouselWordItem']
_COLOR = DESCRIPTOR.message_types_by_name['Color']
_DYNAMICACTMORECARD = DESCRIPTOR.message_types_by_name['DynamicActMoreCard']
_DYNAMICCARD = DESCRIPTOR.message_types_by_name['DynamicCard']
_DYNAMICMORECARD = DESCRIPTOR.message_types_by_name['DynamicMoreCard']
_DYNAMICPARAMS = DESCRIPTOR.message_types_by_name['DynamicParams']
_DYNAMICREQ = DESCRIPTOR.message_types_by_name['DynamicReq']
_DYNAMICRESP = DESCRIPTOR.message_types_by_name['DynamicResp']
_EDITORPARAMS = DESCRIPTOR.message_types_by_name['EditorParams']
_EDITORRECOMMENDCARD = DESCRIPTOR.message_types_by_name['EditorRecommendCard']
_EDITORREQ = DESCRIPTOR.message_types_by_name['EditorReq']
_EDITORRESP = DESCRIPTOR.message_types_by_name['EditorResp']
_GAMECARD = DESCRIPTOR.message_types_by_name['GameCard']
_HEADERCARD = DESCRIPTOR.message_types_by_name['HeaderCard']
_IMAGETITLECARD = DESCRIPTOR.message_types_by_name['ImageTitleCard']
_INDEXREQ = DESCRIPTOR.message_types_by_name['IndexReq']
_INLINEINDEXREQ = DESCRIPTOR.message_types_by_name['InlineIndexReq']
_LAYERDYNAMIC = DESCRIPTOR.message_types_by_name['LayerDynamic']
_LIVECARD = DESCRIPTOR.message_types_by_name['LiveCard']
_LIVEITEM = DESCRIPTOR.message_types_by_name['LiveItem']
_MODULE = DESCRIPTOR.message_types_by_name['Module']
_MODULEITEM = DESCRIPTOR.message_types_by_name['ModuleItem']
_PAGERESP = DESCRIPTOR.message_types_by_name['PageResp']
_PAGESHARE = DESCRIPTOR.message_types_by_name['PageShare']
_PARTICIPATIONCARD = DESCRIPTOR.message_types_by_name['ParticipationCard']
_PARTICIPATIONCARDITEM = DESCRIPTOR.message_types_by_name['ParticipationCardItem']
_PLAYERDIMENSION = DESCRIPTOR.message_types_by_name['PlayerDimension']
_REPORTDIC = DESCRIPTOR.message_types_by_name['ReportDic']
_RESOURCECARD = DESCRIPTOR.message_types_by_name['ResourceCard']
_RESOURCEMORECARD = DESCRIPTOR.message_types_by_name['ResourceMoreCard']
_RESOURCEPARAMS = DESCRIPTOR.message_types_by_name['ResourceParams']
_RESOURCEREQ = DESCRIPTOR.message_types_by_name['ResourceReq']
_RESOURCERESP = DESCRIPTOR.message_types_by_name['ResourceResp']
_SETTING = DESCRIPTOR.message_types_by_name['Setting']
_SHARE = DESCRIPTOR.message_types_by_name['Share']
_SUBPAGEDATA = DESCRIPTOR.message_types_by_name['SubpageData']
_SUBPAGETAB = DESCRIPTOR.message_types_by_name['SubpageTab']
_TABINDEXREQ = DESCRIPTOR.message_types_by_name['TabIndexReq']
_TEXTCARD = DESCRIPTOR.message_types_by_name['TextCard']
_TEXTTITLECARD = DESCRIPTOR.message_types_by_name['TextTitleCard']
_TOPTAB = DESCRIPTOR.message_types_by_name['TopTab']
_TOPICINDEXREQ = DESCRIPTOR.message_types_by_name['TopicIndexReq']
_VIDEOCARD = DESCRIPTOR.message_types_by_name['VideoCard']
_VIDEOMORECARD = DESCRIPTOR.message_types_by_name['VideoMoreCard']
_VIDEOPARAMS = DESCRIPTOR.message_types_by_name['VideoParams']
_VIDEOREQ = DESCRIPTOR.message_types_by_name['VideoReq']
_VIDEORESP = DESCRIPTOR.message_types_by_name['VideoResp']
_VIDEORIGHTS = DESCRIPTOR.message_types_by_name['VideoRights']
Badge = _reflection.GeneratedProtocolMessageType('Badge', (_message.Message,), {
  'DESCRIPTOR' : _BADGE,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.Badge)
  })
_sym_db.RegisterMessage(Badge)

CarouselImgCard = _reflection.GeneratedProtocolMessageType('CarouselImgCard', (_message.Message,), {
  'DESCRIPTOR' : _CAROUSELIMGCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.CarouselImgCard)
  })
_sym_db.RegisterMessage(CarouselImgCard)

CarouselImgItem = _reflection.GeneratedProtocolMessageType('CarouselImgItem', (_message.Message,), {
  'DESCRIPTOR' : _CAROUSELIMGITEM,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.CarouselImgItem)
  })
_sym_db.RegisterMessage(CarouselImgItem)

CarouselWordCard = _reflection.GeneratedProtocolMessageType('CarouselWordCard', (_message.Message,), {
  'DESCRIPTOR' : _CAROUSELWORDCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.CarouselWordCard)
  })
_sym_db.RegisterMessage(CarouselWordCard)

CarouselWordItem = _reflection.GeneratedProtocolMessageType('CarouselWordItem', (_message.Message,), {
  'DESCRIPTOR' : _CAROUSELWORDITEM,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.CarouselWordItem)
  })
_sym_db.RegisterMessage(CarouselWordItem)

Color = _reflection.GeneratedProtocolMessageType('Color', (_message.Message,), {
  'DESCRIPTOR' : _COLOR,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.Color)
  })
_sym_db.RegisterMessage(Color)

DynamicActMoreCard = _reflection.GeneratedProtocolMessageType('DynamicActMoreCard', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICACTMORECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicActMoreCard)
  })
_sym_db.RegisterMessage(DynamicActMoreCard)

DynamicCard = _reflection.GeneratedProtocolMessageType('DynamicCard', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicCard)
  })
_sym_db.RegisterMessage(DynamicCard)

DynamicMoreCard = _reflection.GeneratedProtocolMessageType('DynamicMoreCard', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICMORECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicMoreCard)
  })
_sym_db.RegisterMessage(DynamicMoreCard)

DynamicParams = _reflection.GeneratedProtocolMessageType('DynamicParams', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICPARAMS,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicParams)
  })
_sym_db.RegisterMessage(DynamicParams)

DynamicReq = _reflection.GeneratedProtocolMessageType('DynamicReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicReq)
  })
_sym_db.RegisterMessage(DynamicReq)

DynamicResp = _reflection.GeneratedProtocolMessageType('DynamicResp', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICRESP,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.DynamicResp)
  })
_sym_db.RegisterMessage(DynamicResp)

EditorParams = _reflection.GeneratedProtocolMessageType('EditorParams', (_message.Message,), {
  'DESCRIPTOR' : _EDITORPARAMS,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.EditorParams)
  })
_sym_db.RegisterMessage(EditorParams)

EditorRecommendCard = _reflection.GeneratedProtocolMessageType('EditorRecommendCard', (_message.Message,), {
  'DESCRIPTOR' : _EDITORRECOMMENDCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.EditorRecommendCard)
  })
_sym_db.RegisterMessage(EditorRecommendCard)

EditorReq = _reflection.GeneratedProtocolMessageType('EditorReq', (_message.Message,), {
  'DESCRIPTOR' : _EDITORREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.EditorReq)
  })
_sym_db.RegisterMessage(EditorReq)

EditorResp = _reflection.GeneratedProtocolMessageType('EditorResp', (_message.Message,), {
  'DESCRIPTOR' : _EDITORRESP,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.EditorResp)
  })
_sym_db.RegisterMessage(EditorResp)

GameCard = _reflection.GeneratedProtocolMessageType('GameCard', (_message.Message,), {
  'DESCRIPTOR' : _GAMECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.GameCard)
  })
_sym_db.RegisterMessage(GameCard)

HeaderCard = _reflection.GeneratedProtocolMessageType('HeaderCard', (_message.Message,), {
  'DESCRIPTOR' : _HEADERCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.HeaderCard)
  })
_sym_db.RegisterMessage(HeaderCard)

ImageTitleCard = _reflection.GeneratedProtocolMessageType('ImageTitleCard', (_message.Message,), {
  'DESCRIPTOR' : _IMAGETITLECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ImageTitleCard)
  })
_sym_db.RegisterMessage(ImageTitleCard)

IndexReq = _reflection.GeneratedProtocolMessageType('IndexReq', (_message.Message,), {
  'DESCRIPTOR' : _INDEXREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.IndexReq)
  })
_sym_db.RegisterMessage(IndexReq)

InlineIndexReq = _reflection.GeneratedProtocolMessageType('InlineIndexReq', (_message.Message,), {
  'DESCRIPTOR' : _INLINEINDEXREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.InlineIndexReq)
  })
_sym_db.RegisterMessage(InlineIndexReq)

LayerDynamic = _reflection.GeneratedProtocolMessageType('LayerDynamic', (_message.Message,), {
  'DESCRIPTOR' : _LAYERDYNAMIC,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.LayerDynamic)
  })
_sym_db.RegisterMessage(LayerDynamic)

LiveCard = _reflection.GeneratedProtocolMessageType('LiveCard', (_message.Message,), {
  'DESCRIPTOR' : _LIVECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.LiveCard)
  })
_sym_db.RegisterMessage(LiveCard)

LiveItem = _reflection.GeneratedProtocolMessageType('LiveItem', (_message.Message,), {
  'DESCRIPTOR' : _LIVEITEM,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.LiveItem)
  })
_sym_db.RegisterMessage(LiveItem)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), {
  'DESCRIPTOR' : _MODULE,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.Module)
  })
_sym_db.RegisterMessage(Module)

ModuleItem = _reflection.GeneratedProtocolMessageType('ModuleItem', (_message.Message,), {
  'DESCRIPTOR' : _MODULEITEM,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ModuleItem)
  })
_sym_db.RegisterMessage(ModuleItem)

PageResp = _reflection.GeneratedProtocolMessageType('PageResp', (_message.Message,), {
  'DESCRIPTOR' : _PAGERESP,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.PageResp)
  })
_sym_db.RegisterMessage(PageResp)

PageShare = _reflection.GeneratedProtocolMessageType('PageShare', (_message.Message,), {
  'DESCRIPTOR' : _PAGESHARE,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.PageShare)
  })
_sym_db.RegisterMessage(PageShare)

ParticipationCard = _reflection.GeneratedProtocolMessageType('ParticipationCard', (_message.Message,), {
  'DESCRIPTOR' : _PARTICIPATIONCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ParticipationCard)
  })
_sym_db.RegisterMessage(ParticipationCard)

ParticipationCardItem = _reflection.GeneratedProtocolMessageType('ParticipationCardItem', (_message.Message,), {
  'DESCRIPTOR' : _PARTICIPATIONCARDITEM,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ParticipationCardItem)
  })
_sym_db.RegisterMessage(ParticipationCardItem)

PlayerDimension = _reflection.GeneratedProtocolMessageType('PlayerDimension', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERDIMENSION,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.PlayerDimension)
  })
_sym_db.RegisterMessage(PlayerDimension)

ReportDic = _reflection.GeneratedProtocolMessageType('ReportDic', (_message.Message,), {
  'DESCRIPTOR' : _REPORTDIC,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ReportDic)
  })
_sym_db.RegisterMessage(ReportDic)

ResourceCard = _reflection.GeneratedProtocolMessageType('ResourceCard', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ResourceCard)
  })
_sym_db.RegisterMessage(ResourceCard)

ResourceMoreCard = _reflection.GeneratedProtocolMessageType('ResourceMoreCard', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEMORECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ResourceMoreCard)
  })
_sym_db.RegisterMessage(ResourceMoreCard)

ResourceParams = _reflection.GeneratedProtocolMessageType('ResourceParams', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEPARAMS,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ResourceParams)
  })
_sym_db.RegisterMessage(ResourceParams)

ResourceReq = _reflection.GeneratedProtocolMessageType('ResourceReq', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ResourceReq)
  })
_sym_db.RegisterMessage(ResourceReq)

ResourceResp = _reflection.GeneratedProtocolMessageType('ResourceResp', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCERESP,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.ResourceResp)
  })
_sym_db.RegisterMessage(ResourceResp)

Setting = _reflection.GeneratedProtocolMessageType('Setting', (_message.Message,), {
  'DESCRIPTOR' : _SETTING,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.Setting)
  })
_sym_db.RegisterMessage(Setting)

Share = _reflection.GeneratedProtocolMessageType('Share', (_message.Message,), {
  'DESCRIPTOR' : _SHARE,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.Share)
  })
_sym_db.RegisterMessage(Share)

SubpageData = _reflection.GeneratedProtocolMessageType('SubpageData', (_message.Message,), {
  'DESCRIPTOR' : _SUBPAGEDATA,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.SubpageData)
  })
_sym_db.RegisterMessage(SubpageData)

SubpageTab = _reflection.GeneratedProtocolMessageType('SubpageTab', (_message.Message,), {
  'DESCRIPTOR' : _SUBPAGETAB,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.SubpageTab)
  })
_sym_db.RegisterMessage(SubpageTab)

TabIndexReq = _reflection.GeneratedProtocolMessageType('TabIndexReq', (_message.Message,), {
  'DESCRIPTOR' : _TABINDEXREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.TabIndexReq)
  })
_sym_db.RegisterMessage(TabIndexReq)

TextCard = _reflection.GeneratedProtocolMessageType('TextCard', (_message.Message,), {
  'DESCRIPTOR' : _TEXTCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.TextCard)
  })
_sym_db.RegisterMessage(TextCard)

TextTitleCard = _reflection.GeneratedProtocolMessageType('TextTitleCard', (_message.Message,), {
  'DESCRIPTOR' : _TEXTTITLECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.TextTitleCard)
  })
_sym_db.RegisterMessage(TextTitleCard)

TopTab = _reflection.GeneratedProtocolMessageType('TopTab', (_message.Message,), {
  'DESCRIPTOR' : _TOPTAB,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.TopTab)
  })
_sym_db.RegisterMessage(TopTab)

TopicIndexReq = _reflection.GeneratedProtocolMessageType('TopicIndexReq', (_message.Message,), {
  'DESCRIPTOR' : _TOPICINDEXREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.TopicIndexReq)
  })
_sym_db.RegisterMessage(TopicIndexReq)

VideoCard = _reflection.GeneratedProtocolMessageType('VideoCard', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOCARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoCard)
  })
_sym_db.RegisterMessage(VideoCard)

VideoMoreCard = _reflection.GeneratedProtocolMessageType('VideoMoreCard', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOMORECARD,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoMoreCard)
  })
_sym_db.RegisterMessage(VideoMoreCard)

VideoParams = _reflection.GeneratedProtocolMessageType('VideoParams', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOPARAMS,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoParams)
  })
_sym_db.RegisterMessage(VideoParams)

VideoReq = _reflection.GeneratedProtocolMessageType('VideoReq', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOREQ,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoReq)
  })
_sym_db.RegisterMessage(VideoReq)

VideoResp = _reflection.GeneratedProtocolMessageType('VideoResp', (_message.Message,), {
  'DESCRIPTOR' : _VIDEORESP,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoResp)
  })
_sym_db.RegisterMessage(VideoResp)

VideoRights = _reflection.GeneratedProtocolMessageType('VideoRights', (_message.Message,), {
  'DESCRIPTOR' : _VIDEORIGHTS,
  '__module__' : 'bilibili.app.nativeact.v1.nativeact_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.nativeact.v1.VideoRights)
  })
_sym_db.RegisterMessage(VideoRights)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BADGE._serialized_start=188
  _BADGE._serialized_end=251
  _CAROUSELIMGCARD._serialized_start=253
  _CAROUSELIMGCARD._serialized_end=353
  _CAROUSELIMGITEM._serialized_start=356
  _CAROUSELIMGITEM._serialized_end=500
  _CAROUSELWORDCARD._serialized_start=502
  _CAROUSELWORDCARD._serialized_end=624
  _CAROUSELWORDITEM._serialized_start=626
  _CAROUSELWORDITEM._serialized_end=661
  _COLOR._serialized_start=664
  _COLOR._serialized_end=1328
  _DYNAMICACTMORECARD._serialized_start=1330
  _DYNAMICACTMORECARD._serialized_end=1439
  _DYNAMICCARD._serialized_start=1441
  _DYNAMICCARD._serialized_end=1509
  _DYNAMICMORECARD._serialized_start=1511
  _DYNAMICMORECARD._serialized_end=1617
  _DYNAMICPARAMS._serialized_start=1620
  _DYNAMICPARAMS._serialized_end=1752
  _DYNAMICREQ._serialized_start=1755
  _DYNAMICREQ._serialized_end=2002
  _DYNAMICRESP._serialized_start=2004
  _DYNAMICRESP._serialized_end=2068
  _EDITORPARAMS._serialized_start=2070
  _EDITORPARAMS._serialized_end=2119
  _EDITORRECOMMENDCARD._serialized_start=2122
  _EDITORRECOMMENDCARD._serialized_end=2628
  _EDITORREQ._serialized_start=2630
  _EDITORREQ._serialized_end=2743
  _EDITORRESP._serialized_start=2745
  _EDITORRESP._serialized_end=2808
  _GAMECARD._serialized_start=2810
  _GAMECARD._serialized_end=2898
  _HEADERCARD._serialized_start=2901
  _HEADERCARD._serialized_end=3103
  _IMAGETITLECARD._serialized_start=3105
  _IMAGETITLECARD._serialized_end=3136
  _INDEXREQ._serialized_start=3139
  _INDEXREQ._serialized_end=3489
  _INLINEINDEXREQ._serialized_start=3492
  _INLINEINDEXREQ._serialized_end=3680
  _LAYERDYNAMIC._serialized_start=3682
  _LAYERDYNAMIC._serialized_end=3766
  _LIVECARD._serialized_start=3768
  _LIVECARD._serialized_end=3850
  _LIVEITEM._serialized_start=3853
  _LIVEITEM._serialized_end=4164
  _MODULE._serialized_start=4167
  _MODULE._serialized_end=4472
  _MODULEITEM._serialized_start=4475
  _MODULEITEM._serialized_end=5706
  _PAGERESP._serialized_start=5709
  _PAGERESP._serialized_end=6238
  _PAGESHARE._serialized_start=6240
  _PAGESHARE._serialized_end=6350
  _PARTICIPATIONCARD._serialized_start=6352
  _PARTICIPATIONCARD._serialized_end=6475
  _PARTICIPATIONCARDITEM._serialized_start=6477
  _PARTICIPATIONCARDITEM._serialized_end=6557
  _PLAYERDIMENSION._serialized_start=6559
  _PLAYERDIMENSION._serialized_end=6623
  _REPORTDIC._serialized_start=6626
  _REPORTDIC._serialized_end=6795
  _RESOURCECARD._serialized_start=6798
  _RESOURCECARD._serialized_end=7125
  _RESOURCEMORECARD._serialized_start=7127
  _RESOURCEMORECARD._serialized_end=7234
  _RESOURCEPARAMS._serialized_start=7236
  _RESOURCEPARAMS._serialized_end=7328
  _RESOURCEREQ._serialized_start=7330
  _RESOURCEREQ._serialized_end=7447
  _RESOURCERESP._serialized_start=7449
  _RESOURCERESP._serialized_end=7514
  _SETTING._serialized_start=7517
  _SETTING._serialized_end=7888
  _SHARE._serialized_start=7890
  _SHARE._serialized_end=7975
  _SUBPAGEDATA._serialized_start=7977
  _SUBPAGEDATA._serialized_end=8074
  _SUBPAGETAB._serialized_start=8076
  _SUBPAGETAB._serialized_end=8118
  _TABINDEXREQ._serialized_start=8121
  _TABINDEXREQ._serialized_end=8331
  _TEXTCARD._serialized_start=8333
  _TEXTCARD._serialized_end=8357
  _TEXTTITLECARD._serialized_start=8359
  _TEXTTITLECARD._serialized_end=8389
  _TOPTAB._serialized_start=8392
  _TOPTAB._serialized_end=8551
  _TOPICINDEXREQ._serialized_start=8554
  _TOPICINDEXREQ._serialized_end=8866
  _VIDEOCARD._serialized_start=8869
  _VIDEOCARD._serialized_end=9260
  _VIDEOMORECARD._serialized_start=9262
  _VIDEOMORECARD._serialized_end=9366
  _VIDEOPARAMS._serialized_start=9368
  _VIDEOPARAMS._serialized_end=9457
  _VIDEOREQ._serialized_start=9459
  _VIDEOREQ._serialized_end=9570
  _VIDEORESP._serialized_start=9572
  _VIDEORESP._serialized_end=9634
  _VIDEORIGHTS._serialized_start=9636
  _VIDEORIGHTS._serialized_end=9706
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FawkesReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONFIG_FIELD_NUMBER: builtins.int
    FF_FIELD_NUMBER: builtins.int
    config: typing.Text
    """客户端在fawkes系统中对应的已发布最新的config版本号"""

    ff: typing.Text
    """客户端在fawkes系统中对应的已发布最新的ff版本号"""

    def __init__(self,
        *,
        config: typing.Text = ...,
        ff: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["config",b"config","ff",b"ff"]) -> None: ...
global___FawkesReply = FawkesReply

class FawkesReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    APPKEY_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    appkey: typing.Text
    """客户端在fawkes系统的唯一名"""

    env: typing.Text
    """客户端在fawkes系统中的环境参数"""

    session_id: typing.Text
    """启动id"""

    def __init__(self,
        *,
        appkey: typing.Text = ...,
        env: typing.Text = ...,
        session_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["appkey",b"appkey","env",b"env","session_id",b"session_id"]) -> None: ...
global___FawkesReq = FawkesReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.im.type.im_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ENUM_FOLD:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ENUM_FOLDEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ENUM_FOLD.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FOLD_NO: _ENUM_FOLD.ValueType  # 0
    """"""

    FOLD_YES: _ENUM_FOLD.ValueType  # 1
    """"""

    FOLD_UNKNOWN: _ENUM_FOLD.ValueType  # 2
    """"""

class ENUM_FOLD(_ENUM_FOLD, metaclass=_ENUM_FOLDEnumTypeWrapper):
    """"""
    pass

FOLD_NO: ENUM_FOLD.ValueType  # 0
""""""

FOLD_YES: ENUM_FOLD.ValueType  # 1
""""""

FOLD_UNKNOWN: ENUM_FOLD.ValueType  # 2
""""""

global___ENUM_FOLD = ENUM_FOLD


class _ENUM_UNREAD_TYPE:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ENUM_UNREAD_TYPEEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ENUM_UNREAD_TYPE.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNREAD_TYPE_ALL: _ENUM_UNREAD_TYPE.ValueType  # 0
    """"""

    UNREAD_TYPE_FOLLOW: _ENUM_UNREAD_TYPE.ValueType  # 1
    """"""

    UNREAD_TYPE_UNFOLLOW: _ENUM_UNREAD_TYPE.ValueType  # 2
    """"""

    UNREAD_TYPE_DUSTBIN: _ENUM_UNREAD_TYPE.ValueType  # 3
    """"""

class ENUM_UNREAD_TYPE(_ENUM_UNREAD_TYPE, metaclass=_ENUM_UNREAD_TYPEEnumTypeWrapper):
    """"""
    pass

UNREAD_TYPE_ALL: ENUM_UNREAD_TYPE.ValueType  # 0
""""""

UNREAD_TYPE_FOLLOW: ENUM_UNREAD_TYPE.ValueType  # 1
""""""

UNREAD_TYPE_UNFOLLOW: ENUM_UNREAD_TYPE.ValueType  # 2
""""""

UNREAD_TYPE_DUSTBIN: ENUM_UNREAD_TYPE.ValueType  # 3
""""""

global___ENUM_UNREAD_TYPE = ENUM_UNREAD_TYPE


class _SESSION_TYPE:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _SESSION_TYPEEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SESSION_TYPE.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _SESSION_TYPE.ValueType  # 0
    """"""

    UN_FOLD_SESSION: _SESSION_TYPE.ValueType  # 1
    """"""

    UN_FOLLOW_SINGLE_SESSION: _SESSION_TYPE.ValueType  # 2
    """"""

    MY_GROUP_SESSION: _SESSION_TYPE.ValueType  # 3
    """"""

    ALL_SESSION: _SESSION_TYPE.ValueType  # 4
    """"""

    DUSTBIN_SESSION: _SESSION_TYPE.ValueType  # 5
    """"""

class SESSION_TYPE(_SESSION_TYPE, metaclass=_SESSION_TYPEEnumTypeWrapper):
    """

    """
    pass

UNKNOWN: SESSION_TYPE.ValueType  # 0
""""""

UN_FOLD_SESSION: SESSION_TYPE.ValueType  # 1
""""""

UN_FOLLOW_SINGLE_SESSION: SESSION_TYPE.ValueType  # 2
""""""

MY_GROUP_SESSION: SESSION_TYPE.ValueType  # 3
""""""

ALL_SESSION: SESSION_TYPE.ValueType  # 4
""""""

DUSTBIN_SESSION: SESSION_TYPE.ValueType  # 5
""""""

global___SESSION_TYPE = SESSION_TYPE


class DummyReq(google.protobuf.message.Message):
    """空请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IDL_FIELD_NUMBER: builtins.int
    idl: builtins.int
    """"""

    def __init__(self,
        *,
        idl: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["idl",b"idl"]) -> None: ...
global___DummyReq = DummyReq

class DummyRsp(google.protobuf.message.Message):
    """空响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___DummyRsp = DummyRsp

class EmotionInfo(google.protobuf.message.Message):
    """表情资源信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    GIF_URL_FIELD_NUMBER: builtins.int
    text: typing.Text
    """表情"""

    url: typing.Text
    """表情url"""

    size: builtins.int
    """表情大小
    0:未知 1:min 2:max
    """

    gif_url: typing.Text
    """gif url"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        url: typing.Text = ...,
        size: builtins.int = ...,
        gif_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gif_url",b"gif_url","size",b"size","text",b"text","url",b"url"]) -> None: ...
global___EmotionInfo = EmotionInfo

class MsgDetail(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_KEY_FIELD_NUMBER: builtins.int
    SEQNO_FIELD_NUMBER: builtins.int
    msg_key: builtins.int
    """"""

    seqno: builtins.int
    """"""

    def __init__(self,
        *,
        msg_key: builtins.int = ...,
        seqno: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_key",b"msg_key","seqno",b"seqno"]) -> None: ...
global___MsgDetail = MsgDetail

class MsgFeedUnreadRsp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class UnreadEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: builtins.int
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    UNREAD_FIELD_NUMBER: builtins.int
    @property
    def unread(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.int]:
        """"""
        pass
    def __init__(self,
        *,
        unread: typing.Optional[typing.Mapping[typing.Text, builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["unread",b"unread"]) -> None: ...
global___MsgFeedUnreadRsp = MsgFeedUnreadRsp

class ReqAckAssisMsg(google.protobuf.message.Message):
    """更新应援团小助手消息已拉取进度-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACK_SEQNO_FIELD_NUMBER: builtins.int
    ack_seqno: builtins.int
    """"""

    def __init__(self,
        *,
        ack_seqno: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_seqno",b"ack_seqno"]) -> None: ...
global___ReqAckAssisMsg = ReqAckAssisMsg

class ReqAckSessions(google.protobuf.message.Message):
    """拉取已读消息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BEGIN_TS_FIELD_NUMBER: builtins.int
    END_TS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    begin_ts: builtins.int
    """"""

    end_ts: builtins.int
    """"""

    size: builtins.int
    """"""

    def __init__(self,
        *,
        begin_ts: builtins.int = ...,
        end_ts: builtins.int = ...,
        size: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_ts",b"begin_ts","end_ts",b"end_ts","size",b"size"]) -> None: ...
global___ReqAckSessions = ReqAckSessions

class ReqBatRmSess(google.protobuf.message.Message):
    """批量删除会话-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___ReqBatRmSess = ReqBatRmSess

class ReqCloseClearUnreadUI(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___ReqCloseClearUnreadUI = ReqCloseClearUnreadUI

class ReqGetMsg(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    MSG_DETAIL_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""

    session_type: builtins.int
    """"""

    @property
    def msg_detail(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MsgDetail]:
        """"""
        pass
    def __init__(self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        msg_detail: typing.Optional[typing.Iterable[global___MsgDetail]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_detail",b"msg_detail","session_type",b"session_type","talker_id",b"talker_id"]) -> None: ...
global___ReqGetMsg = ReqGetMsg

class ReqGetSessions(google.protobuf.message.Message):
    """拉取会话记录列表-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BEGIN_TS_FIELD_NUMBER: builtins.int
    END_TS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    UNFOLLOW_FOLD_FIELD_NUMBER: builtins.int
    GROUP_FOLD_FIELD_NUMBER: builtins.int
    SORT_RULE_FIELD_NUMBER: builtins.int
    TEENAGER_MODE_FIELD_NUMBER: builtins.int
    LESSONS_MODE_FIELD_NUMBER: builtins.int
    begin_ts: builtins.int
    """"""

    end_ts: builtins.int
    """"""

    size: builtins.int
    """"""

    session_type: builtins.int
    """"""

    unfollow_fold: builtins.int
    """"""

    group_fold: builtins.int
    """"""

    sort_rule: builtins.int
    """"""

    teenager_mode: builtins.int
    """青少年模式"""

    lessons_mode: builtins.int
    """课堂模式"""

    def __init__(self,
        *,
        begin_ts: builtins.int = ...,
        end_ts: builtins.int = ...,
        size: builtins.int = ...,
        session_type: builtins.int = ...,
        unfollow_fold: builtins.int = ...,
        group_fold: builtins.int = ...,
        sort_rule: builtins.int = ...,
        teenager_mode: builtins.int = ...,
        lessons_mode: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_ts",b"begin_ts","end_ts",b"end_ts","group_fold",b"group_fold","lessons_mode",b"lessons_mode","session_type",b"session_type","size",b"size","sort_rule",b"sort_rule","teenager_mode",b"teenager_mode","unfollow_fold",b"unfollow_fold"]) -> None: ...
global___ReqGetSessions = ReqGetSessions

class ReqGetSpecificSessions(google.protobuf.message.Message):
    """-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TALKER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def talker_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimpleSession]:
        """具体会话详情"""
        pass
    def __init__(self,
        *,
        talker_sessions: typing.Optional[typing.Iterable[global___SimpleSession]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["talker_sessions",b"talker_sessions"]) -> None: ...
global___ReqGetSpecificSessions = ReqGetSpecificSessions

class ReqGroupAssisMsg(google.protobuf.message.Message):
    """应援团消息助手-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CLIENT_SEQNO_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    client_seqno: builtins.int
    """"""

    size: builtins.int
    """"""

    def __init__(self,
        *,
        client_seqno: builtins.int = ...,
        size: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_seqno",b"client_seqno","size",b"size"]) -> None: ...
global___ReqGroupAssisMsg = ReqGroupAssisMsg

class ReqLiveInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    TALKER_ID_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""

    talker_id: builtins.int
    """"""

    def __init__(self,
        *,
        uid: builtins.int = ...,
        talker_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["talker_id",b"talker_id","uid",b"uid"]) -> None: ...
global___ReqLiveInfo = ReqLiveInfo

class ReqNewSessions(google.protobuf.message.Message):
    """拉取新消息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BEGIN_TS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TEENAGER_MODE_FIELD_NUMBER: builtins.int
    LESSONS_MODE_FIELD_NUMBER: builtins.int
    begin_ts: builtins.int
    """"""

    size: builtins.int
    """"""

    teenager_mode: builtins.int
    """"""

    lessons_mode: builtins.int
    """课堂模式"""

    def __init__(self,
        *,
        begin_ts: builtins.int = ...,
        size: builtins.int = ...,
        teenager_mode: builtins.int = ...,
        lessons_mode: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_ts",b"begin_ts","lessons_mode",b"lessons_mode","size",b"size","teenager_mode",b"teenager_mode"]) -> None: ...
global___ReqNewSessions = ReqNewSessions

class ReqRelationSync(google.protobuf.message.Message):
    """同步关系-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CLIENT_RELATION_OPLOG_SEQNO_FIELD_NUMBER: builtins.int
    client_relation_oplog_seqno: builtins.int
    """客户端当前seqno"""

    def __init__(self,
        *,
        client_relation_oplog_seqno: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_relation_oplog_seqno",b"client_relation_oplog_seqno"]) -> None: ...
global___ReqRelationSync = ReqRelationSync

class ReqRemoveSession(google.protobuf.message.Message):
    """删除会话记录-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""

    session_type: builtins.int
    """"""

    def __init__(self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_type",b"session_type","talker_id",b"talker_id"]) -> None: ...
global___ReqRemoveSession = ReqRemoveSession

class ReqSendMsg(google.protobuf.message.Message):
    """发送消息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_FIELD_NUMBER: builtins.int
    COOKIE_FIELD_NUMBER: builtins.int
    COOKIE2_FIELD_NUMBER: builtins.int
    ERROR_CODE_FIELD_NUMBER: builtins.int
    DEV_ID_FIELD_NUMBER: builtins.int
    @property
    def msg(self) -> bilibili.im.type.im_pb2.Msg:
        """消息内容"""
        pass
    cookie: typing.Text
    """"""

    cookie2: typing.Text
    """"""

    error_code: builtins.int
    """"""

    dev_id: typing.Text
    """"""

    def __init__(self,
        *,
        msg: typing.Optional[bilibili.im.type.im_pb2.Msg] = ...,
        cookie: typing.Text = ...,
        cookie2: typing.Text = ...,
        error_code: builtins.int = ...,
        dev_id: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["msg",b"msg"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cookie",b"cookie","cookie2",b"cookie2","dev_id",b"dev_id","error_code",b"error_code","msg",b"msg"]) -> None: ...
global___ReqSendMsg = ReqSendMsg

class ReqSessionDetail(google.protobuf.message.Message):
    """拉取会话详情-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""

    session_type: builtins.int
    """"""

    uid: builtins.int
    """"""

    def __init__(self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        uid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_type",b"session_type","talker_id",b"talker_id","uid",b"uid"]) -> None: ...
global___ReqSessionDetail = ReqSessionDetail

class ReqSessionDetails(google.protobuf.message.Message):
    """批量拉取会话详情-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SESS_IDS_FIELD_NUMBER: builtins.int
    @property
    def sess_ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReqSessionDetail]:
        """会话详情请求列表"""
        pass
    def __init__(self,
        *,
        sess_ids: typing.Optional[typing.Iterable[global___ReqSessionDetail]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sess_ids",b"sess_ids"]) -> None: ...
global___ReqSessionDetails = ReqSessionDetails

class ReqSessionMsg(google.protobuf.message.Message):
    """同步版本拉取消息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    END_SEQNO_FIELD_NUMBER: builtins.int
    BEGIN_SEQNO_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    DEV_ID_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""

    session_type: builtins.int
    """"""

    end_seqno: builtins.int
    """"""

    begin_seqno: builtins.int
    """"""

    size: builtins.int
    """"""

    order: builtins.int
    """"""

    dev_id: typing.Text
    """"""

    def __init__(self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        end_seqno: builtins.int = ...,
        begin_seqno: builtins.int = ...,
        size: builtins.int = ...,
        order: builtins.int = ...,
        dev_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin_seqno",b"begin_seqno","dev_id",b"dev_id","end_seqno",b"end_seqno","order",b"order","session_type",b"session_type","size",b"size","talker_id",b"talker_id"]) -> None: ...
global___ReqSessionMsg = ReqSessionMsg

class ReqSetTop(google.protobuf.message.Message):
    """置顶聊天-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    OP_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""

    session_type: builtins.int
    """"""

    op_type: builtins.int
    """
    0:置顶 1:取消置顶
    """

    def __init__(self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        op_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["op_type",b"op_type","session_type",b"session_type","talker_id",b"talker_id"]) -> None: ...
global___ReqSetTop = ReqSetTop

class ReqShareList(google.protobuf.message.Message):
    """拉取最近私信分享列表-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SIZE_FIELD_NUMBER: builtins.int
    size: builtins.int
    """分页大小 最大20"""

    def __init__(self,
        *,
        size: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["size",b"size"]) -> None: ...
global___ReqShareList = ReqShareList

class ReqShowClearUnreadUI(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UNREAD_TYPE_FIELD_NUMBER: builtins.int
    SHOW_UNFOLLOW_LIST_FIELD_NUMBER: builtins.int
    SHOW_DUSTBIN_FIELD_NUMBER: builtins.int
    unread_type: builtins.int
    """"""

    show_unfollow_list: builtins.int
    """"""

    show_dustbin: builtins.int
    """"""

    def __init__(self,
        *,
        unread_type: builtins.int = ...,
        show_unfollow_list: builtins.int = ...,
        show_dustbin: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show_dustbin",b"show_dustbin","show_unfollow_list",b"show_unfollow_list","unread_type",b"unread_type"]) -> None: ...
global___ReqShowClearUnreadUI = ReqShowClearUnreadUI

class ReqSingleUnread(google.protobuf.message.Message):
    """未读私信数-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UNREAD_TYPE_FIELD_NUMBER: builtins.int
    SHOW_UNFOLLOW_LIST_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    SHOW_DUSTBIN_FIELD_NUMBER: builtins.int
    unread_type: builtins.int
    """"""

    show_unfollow_list: builtins.int
    """"""

    uid: builtins.int
    """"""

    show_dustbin: builtins.int
    """"""

    def __init__(self,
        *,
        unread_type: builtins.int = ...,
        show_unfollow_list: builtins.int = ...,
        uid: builtins.int = ...,
        show_dustbin: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show_dustbin",b"show_dustbin","show_unfollow_list",b"show_unfollow_list","uid",b"uid","unread_type",b"unread_type"]) -> None: ...
global___ReqSingleUnread = ReqSingleUnread

class ReqSpecificSingleUnread(google.protobuf.message.Message):
    """-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TALKER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def talker_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimpleSession]:
        """具体会话详情"""
        pass
    def __init__(self,
        *,
        talker_sessions: typing.Optional[typing.Iterable[global___SimpleSession]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["talker_sessions",b"talker_sessions"]) -> None: ...
global___ReqSpecificSingleUnread = ReqSpecificSingleUnread

class ReqSyncAck(google.protobuf.message.Message):
    """确认同步进度-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CLIENT_SEQNO_FIELD_NUMBER: builtins.int
    client_seqno: builtins.int
    """"""

    def __init__(self,
        *,
        client_seqno: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_seqno",b"client_seqno"]) -> None: ...
global___ReqSyncAck = ReqSyncAck

class ReqTotalUnread(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UNREAD_TYPE_FIELD_NUMBER: builtins.int
    SHOW_UNFOLLOW_LIST_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    SHOW_DUSTBIN_FIELD_NUMBER: builtins.int
    SINGLEUNREAD_ON_FIELD_NUMBER: builtins.int
    MSGFEED_ON_FIELD_NUMBER: builtins.int
    SYSUP_ON_FIELD_NUMBER: builtins.int
    unread_type: builtins.int
    """"""

    show_unfollow_list: builtins.int
    """"""

    uid: builtins.int
    """"""

    show_dustbin: builtins.int
    """"""

    singleunread_on: builtins.int
    """"""

    msgfeed_on: builtins.int
    """"""

    sysup_on: builtins.int
    """"""

    def __init__(self,
        *,
        unread_type: builtins.int = ...,
        show_unfollow_list: builtins.int = ...,
        uid: builtins.int = ...,
        show_dustbin: builtins.int = ...,
        singleunread_on: builtins.int = ...,
        msgfeed_on: builtins.int = ...,
        sysup_on: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msgfeed_on",b"msgfeed_on","show_dustbin",b"show_dustbin","show_unfollow_list",b"show_unfollow_list","singleunread_on",b"singleunread_on","sysup_on",b"sysup_on","uid",b"uid","unread_type",b"unread_type"]) -> None: ...
global___ReqTotalUnread = ReqTotalUnread

class ReqUpdateAck(google.protobuf.message.Message):
    """更新已读进度-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    ACK_SEQNO_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """聊天对象uid，可以为用户id或者为群id"""

    session_type: builtins.int
    """会话类型"""

    ack_seqno: builtins.int
    """已读的最大seqno"""

    def __init__(self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        ack_seqno: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ack_seqno",b"ack_seqno","session_type",b"session_type","talker_id",b"talker_id"]) -> None: ...
global___ReqUpdateAck = ReqUpdateAck

class ReqUpdateIntercept(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    TALKER_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""

    talker_id: builtins.int
    """"""

    status: builtins.int
    """"""

    def __init__(self,
        *,
        uid: builtins.int = ...,
        talker_id: builtins.int = ...,
        status: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status",b"status","talker_id",b"talker_id","uid",b"uid"]) -> None: ...
global___ReqUpdateIntercept = ReqUpdateIntercept

class ReqUpdateTotalUnread(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___ReqUpdateTotalUnread = ReqUpdateTotalUnread

class RspCloseClearUnreadUI(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___RspCloseClearUnreadUI = RspCloseClearUnreadUI

class RspGetMsg(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_FIELD_NUMBER: builtins.int
    @property
    def msg(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.Msg]:
        """"""
        pass
    def __init__(self,
        *,
        msg: typing.Optional[typing.Iterable[bilibili.im.type.im_pb2.Msg]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg",b"msg"]) -> None: ...
global___RspGetMsg = RspGetMsg

class RspLiveInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIVE_STATUS_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    live_status: builtins.int
    """"""

    jump_url: typing.Text
    """"""

    def __init__(self,
        *,
        live_status: builtins.int = ...,
        jump_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_url",b"jump_url","live_status",b"live_status"]) -> None: ...
global___RspLiveInfo = RspLiveInfo

class RspMyGroupUnread(google.protobuf.message.Message):
    """我创建的应援团未读数-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UNREAD_COUNT_FIELD_NUMBER: builtins.int
    unread_count: builtins.int
    """未读消息数"""

    def __init__(self,
        *,
        unread_count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["unread_count",b"unread_count"]) -> None: ...
global___RspMyGroupUnread = RspMyGroupUnread

class RspRelationSync(google.protobuf.message.Message):
    """同步关系-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FULL_FIELD_NUMBER: builtins.int
    RELATION_LOGS_FIELD_NUMBER: builtins.int
    FRIEND_LIST_FIELD_NUMBER: builtins.int
    SERVER_RELATION_OPLOG_SEQNO_FIELD_NUMBER: builtins.int
    GROUP_LIST_FIELD_NUMBER: builtins.int
    full: builtins.int
    """"""

    @property
    def relation_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.RelationLog]:
        """增量日志"""
        pass
    @property
    def friend_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.FriendRelation]:
        """全量列表"""
        pass
    server_relation_oplog_seqno: builtins.int
    """服务器端最大的relation seqno"""

    @property
    def group_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.GroupRelation]:
        """全量列表"""
        pass
    def __init__(self,
        *,
        full: builtins.int = ...,
        relation_logs: typing.Optional[typing.Iterable[bilibili.im.type.im_pb2.RelationLog]] = ...,
        friend_list: typing.Optional[typing.Iterable[bilibili.im.type.im_pb2.FriendRelation]] = ...,
        server_relation_oplog_seqno: builtins.int = ...,
        group_list: typing.Optional[typing.Iterable[bilibili.im.type.im_pb2.GroupRelation]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["friend_list",b"friend_list","full",b"full","group_list",b"group_list","relation_logs",b"relation_logs","server_relation_oplog_seqno",b"server_relation_oplog_seqno"]) -> None: ...
global___RspRelationSync = RspRelationSync

class RspSendMsg(google.protobuf.message.Message):
    """发送消息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_KEY_FIELD_NUMBER: builtins.int
    E_INFOS_FIELD_NUMBER: builtins.int
    MSG_CONTENT_FIELD_NUMBER: builtins.int
    KEY_HIT_INFOS_FIELD_NUMBER: builtins.int
    msg_key: builtins.int
    """"""

    @property
    def e_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EmotionInfo]:
        """表情资源信息"""
        pass
    msg_content: typing.Text
    """"""

    @property
    def key_hit_infos(self) -> bilibili.im.type.im_pb2.KeyHitInfos:
        """"""
        pass
    def __init__(self,
        *,
        msg_key: builtins.int = ...,
        e_infos: typing.Optional[typing.Iterable[global___EmotionInfo]] = ...,
        msg_content: typing.Text = ...,
        key_hit_infos: typing.Optional[bilibili.im.type.im_pb2.KeyHitInfos] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key_hit_infos",b"key_hit_infos"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_infos",b"e_infos","key_hit_infos",b"key_hit_infos","msg_content",b"msg_content","msg_key",b"msg_key"]) -> None: ...
global___RspSendMsg = RspSendMsg

class RspSessionDetails(google.protobuf.message.Message):
    """批量拉取会话详情-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SESS_INFOS_FIELD_NUMBER: builtins.int
    @property
    def sess_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.SessionInfo]:
        """会话详情列表"""
        pass
    def __init__(self,
        *,
        sess_infos: typing.Optional[typing.Iterable[bilibili.im.type.im_pb2.SessionInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sess_infos",b"sess_infos"]) -> None: ...
global___RspSessionDetails = RspSessionDetails

class RspSessionMsg(google.protobuf.message.Message):
    """同步版本拉取消息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGES_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    MIN_SEQNO_FIELD_NUMBER: builtins.int
    MAX_SEQNO_FIELD_NUMBER: builtins.int
    E_INFOS_FIELD_NUMBER: builtins.int
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.Msg]:
        """"""
        pass
    has_more: builtins.int
    """"""

    min_seqno: builtins.int
    """"""

    max_seqno: builtins.int
    """"""

    @property
    def e_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EmotionInfo]:
        """表情资源信息"""
        pass
    def __init__(self,
        *,
        messages: typing.Optional[typing.Iterable[bilibili.im.type.im_pb2.Msg]] = ...,
        has_more: builtins.int = ...,
        min_seqno: builtins.int = ...,
        max_seqno: builtins.int = ...,
        e_infos: typing.Optional[typing.Iterable[global___EmotionInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_infos",b"e_infos","has_more",b"has_more","max_seqno",b"max_seqno","messages",b"messages","min_seqno",b"min_seqno"]) -> None: ...
global___RspSessionMsg = RspSessionMsg

class RspSessions(google.protobuf.message.Message):
    """拉取消息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class SystemMsgEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    SESSION_LIST_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    ANTI_DISTURB_CLEANING_FIELD_NUMBER: builtins.int
    IS_ADDRESS_LIST_EMPTY_FIELD_NUMBER: builtins.int
    SYSTEM_MSG_FIELD_NUMBER: builtins.int
    SHOW_LEVEL_FIELD_NUMBER: builtins.int
    @property
    def session_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.im.type.im_pb2.SessionInfo]:
        """"""
        pass
    has_more: builtins.int
    """"""

    anti_disturb_cleaning: builtins.bool
    """标记反垃圾会话是否在清理中"""

    is_address_list_empty: builtins.int
    """当session_list为空时，会返回该字段用于判断通讯录是否为空，1表示空，0表示非空"""

    @property
    def system_msg(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """"""
        pass
    show_level: builtins.bool
    """"""

    def __init__(self,
        *,
        session_list: typing.Optional[typing.Iterable[bilibili.im.type.im_pb2.SessionInfo]] = ...,
        has_more: builtins.int = ...,
        anti_disturb_cleaning: builtins.bool = ...,
        is_address_list_empty: builtins.int = ...,
        system_msg: typing.Optional[typing.Mapping[builtins.int, builtins.int]] = ...,
        show_level: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anti_disturb_cleaning",b"anti_disturb_cleaning","has_more",b"has_more","is_address_list_empty",b"is_address_list_empty","session_list",b"session_list","show_level",b"show_level","system_msg",b"system_msg"]) -> None: ...
global___RspSessions = RspSessions

class RspShareList(google.protobuf.message.Message):
    """拉取最近私信分享列表-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SESSION_LIST_FIELD_NUMBER: builtins.int
    ISADDRESSLISTEMPTY_FIELD_NUMBER: builtins.int
    @property
    def session_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShareSessionInfo]:
        """最近会话列表"""
        pass
    IsAddressListEmpty: builtins.int
    """"""

    def __init__(self,
        *,
        session_list: typing.Optional[typing.Iterable[global___ShareSessionInfo]] = ...,
        IsAddressListEmpty: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["IsAddressListEmpty",b"IsAddressListEmpty","session_list",b"session_list"]) -> None: ...
global___RspShareList = RspShareList

class RspShowClearUnreadUI(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DISPLAY_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    display: builtins.bool
    """"""

    text: typing.Text
    """"""

    def __init__(self,
        *,
        display: builtins.bool = ...,
        text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display",b"display","text",b"text"]) -> None: ...
global___RspShowClearUnreadUI = RspShowClearUnreadUI

class RspSingleUnread(google.protobuf.message.Message):
    """未读私信数-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UNFOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    FOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    UNFOLLOW_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_UNREAD_FIELD_NUMBER: builtins.int
    unfollow_unread: builtins.int
    """未关注用户私信数"""

    follow_unread: builtins.int
    """已关注用户私信数"""

    unfollow_push_msg: builtins.int
    """未关注人列表是否有新业务通知"""

    dustbin_push_msg: builtins.int
    """"""

    dustbin_unread: builtins.int
    """"""

    def __init__(self,
        *,
        unfollow_unread: builtins.int = ...,
        follow_unread: builtins.int = ...,
        unfollow_push_msg: builtins.int = ...,
        dustbin_push_msg: builtins.int = ...,
        dustbin_unread: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dustbin_push_msg",b"dustbin_push_msg","dustbin_unread",b"dustbin_unread","follow_unread",b"follow_unread","unfollow_push_msg",b"unfollow_push_msg","unfollow_unread",b"unfollow_unread"]) -> None: ...
global___RspSingleUnread = RspSingleUnread

class RspSpecificSingleUnread(google.protobuf.message.Message):
    """-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class TalkerUnreadCntEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    TALKERUNREADCNT_FIELD_NUMBER: builtins.int
    ALLUNREADCNT_FIELD_NUMBER: builtins.int
    @property
    def talkerUnreadCnt(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """key -> 用户uid, value ->未读数"""
        pass
    allUnreadCnt: builtins.int
    """总未读数"""

    def __init__(self,
        *,
        talkerUnreadCnt: typing.Optional[typing.Mapping[builtins.int, builtins.int]] = ...,
        allUnreadCnt: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allUnreadCnt",b"allUnreadCnt","talkerUnreadCnt",b"talkerUnreadCnt"]) -> None: ...
global___RspSpecificSingleUnread = RspSpecificSingleUnread

class RspSyncAck(google.protobuf.message.Message):
    """确认同步进度-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___RspSyncAck = RspSyncAck

class RspTotalUnread(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SESSION_SINGLE_UNREAD_FIELD_NUMBER: builtins.int
    MSG_FEED_UNREAD_FIELD_NUMBER: builtins.int
    SYS_MSG_INTERFACE_LAST_MSG_FIELD_NUMBER: builtins.int
    TOTAL_UNREAD_FIELD_NUMBER: builtins.int
    @property
    def session_single_unread(self) -> global___SessionSingleUnreadRsp:
        """"""
        pass
    @property
    def msg_feed_unread(self) -> global___MsgFeedUnreadRsp:
        """"""
        pass
    @property
    def sys_msg_interface_last_msg(self) -> global___SysMsgInterfaceLastMsgRsp:
        """"""
        pass
    total_unread: builtins.int
    """"""

    def __init__(self,
        *,
        session_single_unread: typing.Optional[global___SessionSingleUnreadRsp] = ...,
        msg_feed_unread: typing.Optional[global___MsgFeedUnreadRsp] = ...,
        sys_msg_interface_last_msg: typing.Optional[global___SysMsgInterfaceLastMsgRsp] = ...,
        total_unread: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["msg_feed_unread",b"msg_feed_unread","session_single_unread",b"session_single_unread","sys_msg_interface_last_msg",b"sys_msg_interface_last_msg"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg_feed_unread",b"msg_feed_unread","session_single_unread",b"session_single_unread","sys_msg_interface_last_msg",b"sys_msg_interface_last_msg","total_unread",b"total_unread"]) -> None: ...
global___RspTotalUnread = RspTotalUnread

class RspUpdateTotalUnread(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___RspUpdateTotalUnread = RspUpdateTotalUnread

class SessionSingleUnreadRsp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UNFOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    FOLLOW_UNREAD_FIELD_NUMBER: builtins.int
    UNFOLLOW_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_PUSH_MSG_FIELD_NUMBER: builtins.int
    DUSTBIN_UNREAD_FIELD_NUMBER: builtins.int
    unfollow_unread: builtins.int
    """"""

    follow_unread: builtins.int
    """"""

    unfollow_push_msg: builtins.int
    """"""

    dustbin_push_msg: builtins.int
    """"""

    dustbin_unread: builtins.int
    """"""

    def __init__(self,
        *,
        unfollow_unread: builtins.int = ...,
        follow_unread: builtins.int = ...,
        unfollow_push_msg: builtins.int = ...,
        dustbin_push_msg: builtins.int = ...,
        dustbin_unread: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dustbin_push_msg",b"dustbin_push_msg","dustbin_unread",b"dustbin_unread","follow_unread",b"follow_unread","unfollow_push_msg",b"unfollow_push_msg","unfollow_unread",b"unfollow_unread"]) -> None: ...
global___SessionSingleUnreadRsp = SessionSingleUnreadRsp

class ShareSessionInfo(google.protobuf.message.Message):
    """会话信息，用于私信分享"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TALKER_ID_FIELD_NUMBER: builtins.int
    TALKER_UNAME_FIELD_NUMBER: builtins.int
    TALKER_ICON_FIELD_NUMBER: builtins.int
    OFFICIAL_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """"""

    talker_uname: typing.Text
    """"""

    talker_icon: typing.Text
    """"""

    official_type: builtins.int
    """认证信息
    -1: 无认证 0:个人认证 1:机构认证
    """

    def __init__(self,
        *,
        talker_id: builtins.int = ...,
        talker_uname: typing.Text = ...,
        talker_icon: typing.Text = ...,
        official_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["official_type",b"official_type","talker_icon",b"talker_icon","talker_id",b"talker_id","talker_uname",b"talker_uname"]) -> None: ...
global___ShareSessionInfo = ShareSessionInfo

class SimpleSession(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TALKER_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    talker_id: builtins.int
    """聊天对象uid，可以为用户id或者为群id"""

    session_type: builtins.int
    """会话类型"""

    def __init__(self,
        *,
        talker_id: builtins.int = ...,
        session_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["session_type",b"session_type","talker_id",b"talker_id"]) -> None: ...
global___SimpleSession = SimpleSession

class SysMsgInterfaceLastMsgRsp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UNREAD_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    unread: builtins.int
    """"""

    title: typing.Text
    """"""

    time: typing.Text
    """"""

    id: builtins.int
    """"""

    def __init__(self,
        *,
        unread: builtins.int = ...,
        title: typing.Text = ...,
        time: typing.Text = ...,
        id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","time",b"time","title",b"title","unread",b"unread"]) -> None: ...
global___SysMsgInterfaceLastMsgRsp = SysMsgInterfaceLastMsgRsp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Arc(google.protobuf.message.Message):
    """稿件基本信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    TYPE_ID_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    COPYRIGHT_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    PUBDATE_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    MISSION_ID_FIELD_NUMBER: builtins.int
    ORDER_ID_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    FORWARD_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    REPORT_RESULT_FIELD_NUMBER: builtins.int
    DYNAMIC_FIELD_NUMBER: builtins.int
    FIRST_CID_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    STAFF_INFO_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    ATTRIBUTE_V2_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""

    videos: builtins.int
    """稿件分P数"""

    type_id: builtins.int
    """分区id"""

    type_name: typing.Text
    """二级分区名"""

    copyright: builtins.int
    """稿件类型
    1:原创 2:转载
    """

    pic: typing.Text
    """稿件封面url"""

    title: typing.Text
    """稿件标题"""

    pubdate: builtins.int
    """稿件发布时间"""

    ctime: builtins.int
    """用户投稿时间"""

    desc: typing.Text
    """稿件简介"""

    state: builtins.int
    """稿件状态"""

    access: builtins.int
    """访问属性
    0:全部可见 10000:登录可见
    """

    attribute: builtins.int
    """属性位配置(现在无了)"""

    tag: typing.Text
    """空"""

    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """空"""
        pass
    duration: builtins.int
    """稿件总时长(单位为秒)"""

    mission_id: builtins.int
    """参与的活动id"""

    order_id: builtins.int
    """绑定的商单id"""

    redirect_url: typing.Text
    """PGC稿件强制重定向url(如番剧、影视)"""

    forward: builtins.int
    """空"""

    @property
    def rights(self) -> global___Rights:
        """控制标志"""
        pass
    @property
    def author(self) -> global___Author:
        """UP主信息"""
        pass
    @property
    def stat(self) -> global___Stat:
        """状态数"""
        pass
    report_result: typing.Text
    """空"""

    dynamic: typing.Text
    """投稿时发送的动态内容"""

    first_cid: builtins.int
    """稿件1P cid"""

    @property
    def dimension(self) -> global___Dimension:
        """稿件1P 分辨率"""
        pass
    @property
    def staff_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaffInfo]:
        """合作组成员列表"""
        pass
    season_id: builtins.int
    """UGC合集id"""

    attribute_v2: builtins.int
    """新版属性位配置(也没用)"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        videos: builtins.int = ...,
        type_id: builtins.int = ...,
        type_name: typing.Text = ...,
        copyright: builtins.int = ...,
        pic: typing.Text = ...,
        title: typing.Text = ...,
        pubdate: builtins.int = ...,
        ctime: builtins.int = ...,
        desc: typing.Text = ...,
        state: builtins.int = ...,
        access: builtins.int = ...,
        attribute: builtins.int = ...,
        tag: typing.Text = ...,
        tags: typing.Optional[typing.Iterable[typing.Text]] = ...,
        duration: builtins.int = ...,
        mission_id: builtins.int = ...,
        order_id: builtins.int = ...,
        redirect_url: typing.Text = ...,
        forward: builtins.int = ...,
        rights: typing.Optional[global___Rights] = ...,
        author: typing.Optional[global___Author] = ...,
        stat: typing.Optional[global___Stat] = ...,
        report_result: typing.Text = ...,
        dynamic: typing.Text = ...,
        first_cid: builtins.int = ...,
        dimension: typing.Optional[global___Dimension] = ...,
        staff_info: typing.Optional[typing.Iterable[global___StaffInfo]] = ...,
        season_id: builtins.int = ...,
        attribute_v2: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author",b"author","dimension",b"dimension","rights",b"rights","stat",b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access",b"access","aid",b"aid","attribute",b"attribute","attribute_v2",b"attribute_v2","author",b"author","copyright",b"copyright","ctime",b"ctime","desc",b"desc","dimension",b"dimension","duration",b"duration","dynamic",b"dynamic","first_cid",b"first_cid","forward",b"forward","mission_id",b"mission_id","order_id",b"order_id","pic",b"pic","pubdate",b"pubdate","redirect_url",b"redirect_url","report_result",b"report_result","rights",b"rights","season_id",b"season_id","staff_info",b"staff_info","stat",b"stat","state",b"state","tag",b"tag","tags",b"tags","title",b"title","type_id",b"type_id","type_name",b"type_name","videos",b"videos"]) -> None: ...
global___Arc = Arc

class Author(google.protobuf.message.Message):
    """UP主信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """UP主mid"""

    name: typing.Text
    """UP主昵称"""

    face: typing.Text
    """UP主头像url"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","mid",b"mid","name",b"name"]) -> None: ...
global___Author = Author

class Dimension(google.protobuf.message.Message):
    """分辨率"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    width: builtins.int
    """宽度"""

    height: builtins.int
    """高度"""

    rotate: builtins.int
    """方向
    0:横屏 1:竖屏
    """

    def __init__(self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        rotate: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height","rotate",b"rotate","width",b"width"]) -> None: ...
global___Dimension = Dimension

class Page(google.protobuf.message.Message):
    """分P信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    PART_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    VID_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    WEBLINK_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """视频cid"""

    page: builtins.int
    """分P序号"""

    part: typing.Text
    """分P标题"""

    duration: builtins.int
    """分P时长(单位为秒)"""

    vid: typing.Text
    """外链vid"""

    desc: typing.Text
    """分P简介"""

    webLink: typing.Text
    """外链url"""

    @property
    def dimension(self) -> global___Dimension:
        """分P分辨率"""
        pass
    def __init__(self,
        *,
        cid: builtins.int = ...,
        page: builtins.int = ...,
        part: typing.Text = ...,
        duration: builtins.int = ...,
        vid: typing.Text = ...,
        desc: typing.Text = ...,
        webLink: typing.Text = ...,
        dimension: typing.Optional[global___Dimension] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension",b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","desc",b"desc","dimension",b"dimension","duration",b"duration","from",b"from","page",b"page","part",b"part","vid",b"vid","webLink",b"webLink"]) -> None: ...
global___Page = Page

class Rights(google.protobuf.message.Message):
    """稿件控制标志"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BP_FIELD_NUMBER: builtins.int
    ELEC_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    MOVIE_FIELD_NUMBER: builtins.int
    PAY_FIELD_NUMBER: builtins.int
    HD5_FIELD_NUMBER: builtins.int
    NO_REPRINT_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    UGC_PAY_FIELD_NUMBER: builtins.int
    IS_COOPERATION_FIELD_NUMBER: builtins.int
    UGC_PAY_PREVIEW_FIELD_NUMBER: builtins.int
    NO_BACKGROUND_FIELD_NUMBER: builtins.int
    bp: builtins.int
    """老版是否付费"""

    elec: builtins.int
    """允许充电"""

    download: builtins.int
    """允许下载"""

    movie: builtins.int
    """是否电影"""

    pay: builtins.int
    """PGC稿件需要付费"""

    hd5: builtins.int
    """是否高码率"""

    no_reprint: builtins.int
    """是否禁止转载标志"""

    autoplay: builtins.int
    """是否允许自动播放"""

    ugc_pay: builtins.int
    """UGC稿件需要付费"""

    is_cooperation: builtins.int
    """是否联合投稿"""

    ugc_pay_preview: builtins.int
    """是否UGC付费预览"""

    no_background: builtins.int
    """是否禁止后台播放"""

    def __init__(self,
        *,
        bp: builtins.int = ...,
        elec: builtins.int = ...,
        download: builtins.int = ...,
        movie: builtins.int = ...,
        pay: builtins.int = ...,
        hd5: builtins.int = ...,
        no_reprint: builtins.int = ...,
        autoplay: builtins.int = ...,
        ugc_pay: builtins.int = ...,
        is_cooperation: builtins.int = ...,
        ugc_pay_preview: builtins.int = ...,
        no_background: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoplay",b"autoplay","bp",b"bp","download",b"download","elec",b"elec","hd5",b"hd5","is_cooperation",b"is_cooperation","movie",b"movie","no_background",b"no_background","no_reprint",b"no_reprint","pay",b"pay","ugc_pay",b"ugc_pay","ugc_pay_preview",b"ugc_pay_preview"]) -> None: ...
global___Rights = Rights

class StaffInfo(google.protobuf.message.Message):
    """合作成员信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """成员mid"""

    title: typing.Text
    """成员角色"""

    attribute: builtins.int
    """属性位
    0:普通 1:赞助商金色标志
    """

    def __init__(self,
        *,
        mid: builtins.int = ...,
        title: typing.Text = ...,
        attribute: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute",b"attribute","mid",b"mid","title",b"title"]) -> None: ...
global___StaffInfo = StaffInfo

class Stat(google.protobuf.message.Message):
    """状态数"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    NOW_RANK_FIELD_NUMBER: builtins.int
    HIS_RANK_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""

    view: builtins.int
    """播放数"""

    danmaku: builtins.int
    """弹幕数"""

    reply: builtins.int
    """评论数"""

    fav: builtins.int
    """收藏数"""

    coin: builtins.int
    """投币数"""

    share: builtins.int
    """分享数"""

    now_rank: builtins.int
    """当前排名"""

    his_rank: builtins.int
    """历史最高排名"""

    like: builtins.int
    """点赞数"""

    dislike: builtins.int
    """点踩数(前端不可见故恒为0)"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        view: builtins.int = ...,
        danmaku: builtins.int = ...,
        reply: builtins.int = ...,
        fav: builtins.int = ...,
        coin: builtins.int = ...,
        share: builtins.int = ...,
        now_rank: builtins.int = ...,
        his_rank: builtins.int = ...,
        like: builtins.int = ...,
        dislike: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","coin",b"coin","danmaku",b"danmaku","dislike",b"dislike","fav",b"fav","his_rank",b"his_rank","like",b"like","now_rank",b"now_rank","reply",b"reply","share",b"share","view",b"view"]) -> None: ...
global___Stat = Stat



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v2/laser.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/broadcast/v2/laser.proto\x12\x15\x62ilibili.broadcast.v2\x1a\x1bgoogle/protobuf/empty.proto\"@\n\x0eLaserEventResp\x12\x0e\n\x06taskid\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x0e\n\x06params\x18\x03 \x01(\t2V\n\x05Laser\x12M\n\nWatchEvent\x12\x16.google.protobuf.Empty\x1a%.bilibili.broadcast.v2.LaserEventResp0\x01\x62\x06proto3')



_LASEREVENTRESP = DESCRIPTOR.message_types_by_name['LaserEventResp']
LaserEventResp = _reflection.GeneratedProtocolMessageType('LaserEventResp', (_message.Message,), {
  'DESCRIPTOR' : _LASEREVENTRESP,
  '__module__' : 'bilibili.broadcast.v2.laser_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v2.LaserEventResp)
  })
_sym_db.RegisterMessage(LaserEventResp)

_LASER = DESCRIPTOR.services_by_name['Laser']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LASEREVENTRESP._serialized_start=89
  _LASEREVENTRESP._serialized_end=153
  _LASER._serialized_start=155
  _LASER._serialized_end=241
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GameNotifyReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    type: builtins.int
    """类型字段"""

    data: typing.Text
    """数据字段"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        data: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data",b"data","type",b"type"]) -> None: ...
global___GameNotifyReply = GameNotifyReply
